# venture-capital-data-toolkit
Package I spun up to make common VC data manipulations easier, without making people learn data science fundamentals.

Use `python3 setup.py sdist bdist_wheel` to prep package
and `twine upload dist/*` to publish